# Confluence Integration
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/confluence-integration#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/confluence-integration#benefits)
  * [Limitations](https://help.sap.com/docs/leanix/ea/confluence-integration#limitations)
  * [Supported Versions](https://help.sap.com/docs/leanix/ea/confluence-integration#supported-versions)
  * [Configuration](https://help.sap.com/docs/leanix/ea/confluence-integration#configuration)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/confluence-integration#prerequisites)
  * [Step 1: Install the SAP LeanIX for Confluence App](https://help.sap.com/docs/leanix/ea/confluence-integration#step-1:-install-the-sap-leanix-for-confluence-app)
  * [Step 2: Configure the SAP LeanIX for Confluence App](https://help.sap.com/docs/leanix/ea/confluence-integration#step-2:-configure-the-sap-leanix-for-confluence-app)


View all
Embed insights about your enterprise architecture in your Confluence pages.
